Module common

Module common 

Structs

AuthorResource
Shared author projection returned across domains (bug, question, …).
Page
Shared response envelope for paginated list endpoints.

Enums

OrganizationRole
The capacity in which a user relates to an organization. User is the fallback for a viewer who is not a member (or is unauthenticated); members are only ever Admin or Member.
RepositoryRole
The capacity in which a user relates to a repository.