Module user

Module user 

Structs

CurrentUserResource
UserCommitResource
A commit as surfaced on a user’s profile. Most fields are optional so that commits in private repositories the viewer cannot access can be returned as a redacted stub (timestamp + redacted: true only)
UserEmailResource
UserMembershipResource
An organization as surfaced from a user’s perspective. It contains basic org info plus the viewer’s own membership metadata (role, joined_at).
UserRepositoryResource
A repository as surfaced on a user’s profile. It contains the viewer-visible subset of repo fields plus the user’s contribution stats.
UserResource