Structs
- Author
Resource - Shared author projection returned across domains (bug, question, …).
- Page
- Shared response envelope for paginated list endpoints.
Enums
- Organization
Role - The capacity in which a user relates to an organization.
Useris the fallback for a viewer who is not a member (or is unauthenticated); members are only everAdminorMember. - Repository
Role - The capacity in which a user relates to a repository.