Module user
args_
api
0.1.0
Module user
Module Items
Structs
In args_
api::
resource
args_api
::
resource
Module
user
Structs

Current
User
Resource
User
Commit
Resource
A commit as surfaced on a user’s profile. Most fields are optional so that commits in private repositories the viewer cannot access can be returned as a redacted stub (timestamp +
redacted: true
only)
User
Email
Resource
User
Membership
Resource
An organization as surfaced from a user’s perspective. It contains basic org info plus the viewer’s own membership metadata (
role
,
joined_at
).
User
Repository
Resource
A repository as surfaced on a user’s profile. It contains the viewer-visible subset of repo fields plus the user’s contribution stats.
User
Resource